import * as React from 'react';
import colorTokens from '@highlight-ui/tokens/dist/colors.json';
import tokens from '@highlight-ui/tokens/dist/tokens.json';
import { invariant, parseMetadata } from '@highlight-ui/utils-commons';
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

var styles = {
  "circle": "CircularProgress-module__3NB5eWuu__v2-2-5",
  "progressIndicator": "CircularProgress-module__He07toFd__v2-2-5"
};
var WIDTH = 22;
var STROKE_WIDTH = tokens['border-width-large'];
var RADIUS = (WIDTH - STROKE_WIDTH * 2) / 2;
var VIEWBOX = "0 0 " + WIDTH + " " + WIDTH;
var CIRCUMFERENCE = RADIUS * Math.PI * 2; // dashlength should cover the whole circumference of the circle

function CircularProgressWithRef(_a, ref) {
  var metadata = _a.metadata,
      percentage = _a.percentage,
      color = _a.color;
  invariant(percentage >= 0 && percentage <= 100, "Percentage must be between 0 and 100");
  var percentageNum = Math.abs(Number(percentage));
  var finalPercentage = percentageNum > 100 ? 100 : percentageNum;
  var dashOffset = CIRCUMFERENCE - CIRCUMFERENCE * finalPercentage / 100; // Scale 100% coverage overlay with the actual percent

  var halfWidth = WIDTH / 2;
  return /*#__PURE__*/React.createElement("div", {
    "aria-valuemax": 100,
    "aria-valuemin": 0,
    "aria-valuenow": percentageNum,
    role: "progressbar",
    ref: ref
  }, /*#__PURE__*/React.createElement("svg", __assign({}, parseMetadata(metadata), {
    width: WIDTH,
    height: WIDTH,
    viewBox: VIEWBOX
  }), /*#__PURE__*/React.createElement("circle", {
    className: styles.circle,
    cx: halfWidth,
    cy: halfWidth,
    r: RADIUS,
    fill: "none"
  }), /*#__PURE__*/React.createElement("circle", {
    className: styles.progressIndicator,
    cx: halfWidth,
    cy: halfWidth,
    r: RADIUS,
    fill: "none",
    transform: "rotate(-90 " + halfWidth + " " + halfWidth + ")",
    style: {
      stroke: color && colorTokens[color],
      strokeDasharray: CIRCUMFERENCE,
      strokeDashoffset: dashOffset
    }
  })));
}

var CircularProgress = /*#__PURE__*/React.forwardRef(CircularProgressWithRef);
export { CircularProgress };
//# sourceMappingURL=index.js.map
